==> zetaalpha_rag_agents-0.0.1.tar.gz: zetaalpha_rag_agents-0.0.1/README.md <==
<p align="center">
  <a href="https://zeta-alpha.com">
    <source media="(prefers-color-scheme: dark)" srcset="https://search.zeta-alpha.com/assets/img/zeta-logo-full-white.svg">
    <source media="(prefers-color-scheme: light)" srcset="https://search.zeta-alpha.com/assets/img/zeta-logo-full-black.svg">
    <img src="https://search.zeta-alpha.com/assets/img/zeta-logo-full-black.svg" alt="Zeta Alpha">
  </a>
</p>
<p align="center">
  <b>Build Intelligence and Drive Results</b>
</p>
<p align="center">
  <em>Advanced AI solutions for the enterprise</em>
</p>

The Agents SDK is designed to provide a flexible, scalable, and efficient framework for building, testing, and deploying LLM agents.

# Quick Start

Create your first conversational AI agent.

```bash
# Install the package
pip install zetaalpha.rag-agents

# Initialize a new project
rag_agents init

# Start the development UI
rag_agents dev
```

https://github.com/user-attachments/assets/ecb56abe-d3b7-4d95-9f6c-78d1e92d864f

For more detailed information and resources, check out the following:

- [Tutorials](https://docs.zeta-alpha.com/gen-ai/customize/getting-started): Step-by-step tutorials to guide you through specific tasks and help you get started quickly.
- [Guides](https://docs.zeta-alpha.com/gen-ai/customize/guides): Practical how-to guides that provide solutions to common problems and use cases.
- [Advance Topics](https://docs.zeta-alpha.com/gen-ai/customize/advanced): In-depth explanations of concepts, features, and the underlying technology to help you understand how things work.
- [Reference](https://docs.zeta-alpha.com/gen-ai/customize/reference): Detailed reference material, including API documentation, configuration options, and command-line tools.

==> zetaalpha_rag_agents-0.0.6.tar.gz: zetaalpha_rag_agents-0.0.6/README.md <==
<p align="center">
  <a href="https://zeta-alpha.com">
    <source media="(prefers-color-scheme: dark)" srcset="https://search.zeta-alpha.com/assets/img/zeta-logo-full-white.svg">
    <source media="(prefers-color-scheme: light)" srcset="https://search.zeta-alpha.com/assets/img/zeta-logo-full-black.svg">
    <img src="https://search.zeta-alpha.com/assets/img/zeta-logo-full-black.svg" alt="Zeta Alpha">
  </a>
</p>
<p align="center">
  <b>Build Intelligence and Drive Results</b>
</p>
<p align="center">
  <em>Advanced AI solutions for the enterprise</em>
</p>

The Agents SDK is designed to provide a flexible, scalable, and efficient framework for building, testing, and deploying LLM agents.

# Quick Start

Create your first conversational AI agent.

```bash
# Install the package
pip install zetaalpha.rag-agents

# Initialize a new project
rag_agents init

# Start the development UI
rag_agents dev
```

https://github.com/user-attachments/assets/2d0b86f8-2d1e-4131-8de9-9d3d1909b631

For more detailed information and resources, check out the following:

- [Tutorials](https://docs.zeta-alpha.com/gen-ai/customize/getting-started): Step-by-step tutorials to guide you through specific tasks and help you get started quickly.
- [Guides](https://docs.zeta-alpha.com/gen-ai/customize/guides): Practical how-to guides that provide solutions to common problems and use cases.
- [Advance Topics](https://docs.zeta-alpha.com/gen-ai/customize/advanced): In-depth explanations of concepts, features, and the underlying technology to help you understand how things work.
- [Reference](https://docs.zeta-alpha.com/gen-ai/customize/reference): Detailed reference material, including API documentation, configuration options, and command-line tools.
